"""
Pydantic Models for CMDB - switch_controller/flow_tracking

Runtime validation models for switch_controller/flow_tracking configuration.
Generated from FortiOS schema version unknown.

Example Usage:
    >>> from hfortix_fortios.models.cmdb.switch_controller.flow_tracking import 
    >>>
    >>> # Create with validation
    >>> obj = (
    ...     name="example",
    ... )
    >>>
    >>> # Validation happens automatically
    >>> # ValidationError raised if constraints violated
"""

from __future__ import annotations

from pydantic import BaseModel, Field, field_validator
from typing import Any, Literal, Optional
from enum import Enum

# ============================================================================
# Child Table Models
# ============================================================================

class FlowTrackingCollectors(BaseModel):
    """
    Child table model for collectors.
    
    Configure collectors for the flow.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
    
    name: str | None = Field(max_length=63, default="", description="Collector name.")    
    ip: str | None = Field(default="0.0.0.0", description="Collector IP address.")    
    port: int | None = Field(ge=0, le=65535, default=0, description="Collector port number(0-65535, default:0, netflow:2055, ipfix:4739).")    
    transport: Literal["udp", "tcp", "sctp"] | None = Field(default="udp", description="Collector L4 transport protocol for exporting packets.")
class FlowTrackingAggregates(BaseModel):
    """
    Child table model for aggregates.
    
    Configure aggregates in which all traffic sessions matching the IP Address will be grouped into the same flow.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
    
    id: int | None = Field(ge=0, le=4294967295, default=0, description="Aggregate id.")    
    ip: str = Field(default="0.0.0.0 0.0.0.0", description="IP address to group all matching traffic sessions to a flow.")
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class FlowTrackingFormatEnum(str, Enum):
    """Allowed values for format field."""
    NETFLOW1 = "netflow1"    NETFLOW5 = "netflow5"    NETFLOW9 = "netflow9"    IPFIX = "ipfix"
class FlowTrackingLevelEnum(str, Enum):
    """Allowed values for level field."""
    VLAN = "vlan"    IP = "ip"    PORT = "port"    PROTO = "proto"    MAC = "mac"

# ============================================================================
# Main Model
# ============================================================================

class FlowTrackingModel(BaseModel):
    """
    Pydantic model for switch_controller/flow_tracking configuration.
    
    Configure FortiSwitch flow tracking and export via ipfix/netflow.
    
    Validation Rules:        - sample_mode: pattern=        - sample_rate: min=0 max=99999 pattern=        - format: pattern=        - collectors: pattern=        - level: pattern=        - max_export_pkt_size: min=512 max=9216 pattern=        - template_export_period: min=1 max=60 pattern=        - timeout_general: min=60 max=604800 pattern=        - timeout_icmp: min=60 max=604800 pattern=        - timeout_max: min=60 max=604800 pattern=        - timeout_tcp: min=60 max=604800 pattern=        - timeout_tcp_fin: min=60 max=604800 pattern=        - timeout_tcp_rst: min=60 max=604800 pattern=        - timeout_udp: min=60 max=604800 pattern=        - aggregates: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    sample_mode: Literal["local", "perimeter", "device-ingress"] | None = Field(default="perimeter", description="Configure sample mode for the flow tracking.")    
    sample_rate: int | None = Field(ge=0, le=99999, default=512, description="Configure sample rate for the perimeter and device-ingress sampling(0 - 99999).")    
    format: FormatEnum | None = Field(default="netflow9", description="Configure flow tracking protocol.")    
    collectors: list[Collectors] = Field(default=None, description="Configure collectors for the flow.")    
    level: LevelEnum | None = Field(default="ip", description="Configure flow tracking level.")    
    max_export_pkt_size: int | None = Field(ge=512, le=9216, default=512, description="Configure flow max export packet size (512-9216, default=512 bytes).")    
    template_export_period: int | None = Field(ge=1, le=60, default=5, description="Configure template export period (1-60, default=5 minutes).")    
    timeout_general: int | None = Field(ge=60, le=604800, default=3600, description="Configure flow session general timeout (60-604800, default=3600 seconds).")    
    timeout_icmp: int | None = Field(ge=60, le=604800, default=300, description="Configure flow session ICMP timeout (60-604800, default=300 seconds).")    
    timeout_max: int | None = Field(ge=60, le=604800, default=604800, description="Configure flow session max timeout (60-604800, default=604800 seconds).")    
    timeout_tcp: int | None = Field(ge=60, le=604800, default=3600, description="Configure flow session TCP timeout (60-604800, default=3600 seconds).")    
    timeout_tcp_fin: int | None = Field(ge=60, le=604800, default=300, description="Configure flow session TCP FIN timeout (60-604800, default=300 seconds).")    
    timeout_tcp_rst: int | None = Field(ge=60, le=604800, default=120, description="Configure flow session TCP RST timeout (60-604800, default=120 seconds).")    
    timeout_udp: int | None = Field(ge=60, le=604800, default=300, description="Configure flow session UDP timeout (60-604800, default=300 seconds).")    
    aggregates: list[Aggregates] = Field(default=None, description="Configure aggregates in which all traffic sessions matching the IP Address will be grouped into the same flow.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "FlowTrackingModel",    "FlowTrackingCollectors",    "FlowTrackingAggregates",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.0
# Generated: 2026-01-09T09:47:38.847585Z
# ============================================================================


"""FortiOS CMDB - Icap category"""

from .profile import Profile
from .server import Server
from .server_group import ServerGroup

__all__ = [
    "Icap",
    "Profile",
    "Server",
    "ServerGroup",
]


class Icap:
    """Icap endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """Icap endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        self.profile = Profile(client)
        self.server = Server(client)
        self.server_group = ServerGroup(client)



"""
Pydantic Models for CMDB - wireless_controller/apcfg_profile

Runtime validation models for wireless_controller/apcfg_profile configuration.
Generated from FortiOS schema version unknown.

Example Usage:
    >>> from hfortix_fortios.models.cmdb.wireless_controller.apcfg_profile import 
    >>>
    >>> # Create with validation
    >>> obj = (
    ...     name=1,
    ...     name="example",
    ... )
    >>>
    >>> # Validation happens automatically
    >>> # ValidationError raised if constraints violated
"""

from __future__ import annotations

from pydantic import BaseModel, Field, field_validator
from typing import Any, Literal, Optional

# ============================================================================
# Child Table Models
# ============================================================================

class ApcfgProfileCommandList(BaseModel):
    """
    Child table model for command-list.
    
    AP local configuration command list.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
    
    id: int | None = Field(ge=1, le=255, default=0, description="Command ID.")    
    type: Literal["non-password", "password"] | None = Field(default="non-password", description="The command type (default = non-password).")    
    name: str | None = Field(max_length=63, default="", description="AP local configuration command name.")    
    value: str | None = Field(max_length=127, default="", description="AP local configuration command value.")    
    passwd_value: Any = Field(max_length=128, default=None, description="AP local configuration command password value.")
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================


# ============================================================================
# Main Model
# ============================================================================

class ApcfgProfileModel(BaseModel):
    """
    Pydantic model for wireless_controller/apcfg_profile configuration.
    
    Configure AP local configuration profiles.
    
    Validation Rules:        - name: max_length=35 pattern=        - ap_family: pattern=        - comment: max_length=255 pattern=        - ac_type: pattern=        - ac_timer: min=3 max=30 pattern=        - ac_ip: pattern=        - ac_port: min=1024 max=49150 pattern=        - command_list: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    name: str | None = Field(max_length=35, default="", description="AP local configuration profile name.")    
    ap_family: Literal["fap", "fap-u", "fap-c"] | None = Field(default="fap", description="FortiAP family type (default = fap).")    
    comment: str | None = Field(max_length=255, default=None, description="Comment.")    
    ac_type: Literal["default", "specify", "apcfg"] | None = Field(default="default", description="Validation controller type (default = default).")    
    ac_timer: int | None = Field(ge=3, le=30, default=10, description="Maximum waiting time for the AP to join the validation controller after applying AP local configuration (3 - 30 min, default = 10).")    
    ac_ip: str | None = Field(default="0.0.0.0", description="IP address of the validation controller that AP must be able to join after applying AP local configuration.")    
    ac_port: int | None = Field(ge=1024, le=49150, default=5246, description="Port of the validation controller that AP must be able to join after applying AP local configuration (1024 - 49150, default = 5246).")    
    command_list: list[CommandList] = Field(default=None, description="AP local configuration command list.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "ApcfgProfileModel",    "ApcfgProfileCommandList",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.0
# Generated: 2026-01-09T09:47:42.364399Z
# ============================================================================


"""Type stubs for LOG category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .current_disk_usage import CurrentDiskUsage, CurrentDiskUsageDictMode, CurrentDiskUsageObjectMode
    from .feature_set import FeatureSet, FeatureSetDictMode, FeatureSetObjectMode
    from .fortianalyzer import Fortianalyzer, FortianalyzerDictMode, FortianalyzerObjectMode
    from .fortianalyzer_queue import FortianalyzerQueue, FortianalyzerQueueDictMode, FortianalyzerQueueObjectMode
    from .forticloud_report_list import ForticloudReportList, ForticloudReportListDictMode, ForticloudReportListObjectMode
    from .historic_daily_remote_logs import HistoricDailyRemoteLogs, HistoricDailyRemoteLogsDictMode, HistoricDailyRemoteLogsObjectMode
    from .hourly_disk_usage import HourlyDiskUsage, HourlyDiskUsageDictMode, HourlyDiskUsageObjectMode
    from .local_report_list import LocalReportList, LocalReportListDictMode, LocalReportListObjectMode
    from .av_archive import AvArchive
    from .device import DeviceDictMode, DeviceObjectMode
    from .forticloud import Forticloud
    from .forticloud_report import ForticloudReport
    from .local_report import LocalReport
    from .policy_archive import PolicyArchive
    from .stats import Stats

__all__ = [
    "CurrentDiskUsage",
    "FeatureSet",
    "Fortianalyzer",
    "FortianalyzerQueue",
    "ForticloudReportList",
    "HistoricDailyRemoteLogs",
    "HourlyDiskUsage",
    "LocalReportList",
    "LogDictMode",
    "LogObjectMode",
]

class LogDictMode:
    """LOG API category for dict response mode.
    
    This class is returned when the client is instantiated with response_mode="dict" (default).
    All endpoints return dict/TypedDict responses by default.
    """
    
    av_archive: AvArchive
    device: DeviceDictMode
    forticloud: Forticloud
    forticloud_report: ForticloudReport
    local_report: LocalReport
    policy_archive: PolicyArchive
    stats: Stats
    current_disk_usage: CurrentDiskUsageDictMode
    feature_set: FeatureSetDictMode
    fortianalyzer: FortianalyzerDictMode
    fortianalyzer_queue: FortianalyzerQueueDictMode
    forticloud_report_list: ForticloudReportListDictMode
    historic_daily_remote_logs: HistoricDailyRemoteLogsDictMode
    hourly_disk_usage: HourlyDiskUsageDictMode
    local_report_list: LocalReportListDictMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize log category with HTTP client."""
        ...


class LogObjectMode:
    """LOG API category for object response mode.
    
    This class is returned when the client is instantiated with response_mode="object".
    All endpoints return FortiObject responses by default.
    """
    
    av_archive: AvArchive
    device: DeviceObjectMode
    forticloud: Forticloud
    forticloud_report: ForticloudReport
    local_report: LocalReport
    policy_archive: PolicyArchive
    stats: Stats
    current_disk_usage: CurrentDiskUsageObjectMode
    feature_set: FeatureSetObjectMode
    fortianalyzer: FortianalyzerObjectMode
    fortianalyzer_queue: FortianalyzerQueueObjectMode
    forticloud_report_list: ForticloudReportListObjectMode
    historic_daily_remote_logs: HistoricDailyRemoteLogsObjectMode
    hourly_disk_usage: HourlyDiskUsageObjectMode
    local_report_list: LocalReportListObjectMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize log category with HTTP client."""
        ...


# Base class for backwards compatibility
class Log:
    """LOG API category."""
    
    av_archive: AvArchive
    device: Device
    forticloud: Forticloud
    forticloud_report: ForticloudReport
    local_report: LocalReport
    policy_archive: PolicyArchive
    stats: Stats
    current_disk_usage: CurrentDiskUsage
    feature_set: FeatureSet
    fortianalyzer: Fortianalyzer
    fortianalyzer_queue: FortianalyzerQueue
    forticloud_report_list: ForticloudReportList
    historic_daily_remote_logs: HistoricDailyRemoteLogs
    hourly_disk_usage: HourlyDiskUsage
    local_report_list: LocalReportList

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize log category with HTTP client."""
        ...



"""
FortiOS LOG API - Fortianalyzer

Log query endpoints for fortianalyzer logs.

Note: LOG endpoints are read-only (GET only) and return log data.
They accept path parameters that are represented as nested classes.

Example Usage:
    >>> fgt.api.log.fortianalyzer.event.vpn.get(rows=100)
    >>> fgt.api.log.fortianalyzer.traffic.forward.get(rows=50)
"""

from __future__ import annotations

from typing import TYPE_CHECKING, Any, Union

if TYPE_CHECKING:
    from collections.abc import Coroutine
    from hfortix_core.http.interface import IHTTPClient


class Fortianalyzer:
    """Fortianalyzer log operations."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize Fortianalyzer endpoint."""
        self._client = client
        self.anomaly = FortianalyzerAnomaly(client)
        self.app_ctrl = FortianalyzerAppCtrl(client)
        self.cifs = FortianalyzerCifs(client)
        self.dlp = FortianalyzerDlp(client)
        self.dns = FortianalyzerDns(client)
        self.emailfilter = FortianalyzerEmailfilter(client)
        self.event = FortianalyzerEvent(client)
        self.file_filter = FortianalyzerFileFilter(client)
        self.gtp = FortianalyzerGtp(client)
        self.ips = FortianalyzerIps(client)
        self.ssh = FortianalyzerSsh(client)
        self.ssl = FortianalyzerSsl(client)
        self.traffic = FortianalyzerTraffic(client)
        self.virus = FortianalyzerVirus(client)
        self.voip = FortianalyzerVoip(client)
        self.waf = FortianalyzerWaf(client)
        self.webfilter = FortianalyzerWebfilter(client)


class FortianalyzerAnomaly:
    """FortianalyzerAnomaly log operations (type=anomaly)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerAnomaly."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get anomaly logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/anomaly/raw", **kwargs)


class FortianalyzerAppCtrl:
    """FortianalyzerAppCtrl log operations (type=app-ctrl)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerAppCtrl."""
        self._client = client
        self.archive = FortianalyzerAppCtrlArchive(client, "app-ctrl")
        self.archive_download = FortianalyzerAppCtrlArchiveDownload(client, "app-ctrl")

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get app_ctrl logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/app-ctrl/raw", **kwargs)


class FortianalyzerAppCtrlArchive:
    """archive operations for app_ctrl."""

    def __init__(self, client: "IHTTPClient", type_value: str):
        """Initialize FortianalyzerAppCtrlArchive."""
        self._client = client
        self._type = type_value

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get archive data for this log type.
        
        Args:
            **kwargs: Additional query parameters
        
        Returns:
            Dict containing archive data
        """
        return self._client.get("log", "/log/fortianalyzer/app-ctrl/archive", **kwargs)


class FortianalyzerAppCtrlArchiveDownload:
    """archive-download operations for app_ctrl."""

    def __init__(self, client: "IHTTPClient", type_value: str):
        """Initialize FortianalyzerAppCtrlArchiveDownload."""
        self._client = client
        self._type = type_value

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get archive-download data for this log type.
        
        Args:
            **kwargs: Additional query parameters
        
        Returns:
            Dict containing archive-download data
        """
        return self._client.get("log", "/log/fortianalyzer/app-ctrl/archive-download", **kwargs)


class FortianalyzerCifs:
    """FortianalyzerCifs log operations (type=cifs)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerCifs."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get cifs logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/cifs/raw", **kwargs)


class FortianalyzerDlp:
    """FortianalyzerDlp log operations (type=dlp)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerDlp."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get dlp logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/dlp/raw", **kwargs)


class FortianalyzerDns:
    """FortianalyzerDns log operations (type=dns)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerDns."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get dns logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/dns/raw", **kwargs)


class FortianalyzerEmailfilter:
    """FortianalyzerEmailfilter log operations (type=emailfilter)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerEmailfilter."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get emailfilter logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/emailfilter/raw", **kwargs)


class FortianalyzerEvent:
    """FortianalyzerEvent log operations."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerEvent."""
        self._client = client
        self.compliance_check = FortianalyzerEventComplianceCheck(client, "compliance-check")
        self.connector = FortianalyzerEventConnector(client, "connector")
        self.endpoint = FortianalyzerEventEndpoint(client, "endpoint")
        self.fortiextender = FortianalyzerEventFortiextender(client, "fortiextender")
        self.ha = FortianalyzerEventHa(client, "ha")
        self.router = FortianalyzerEventRouter(client, "router")
        self.security_rating = FortianalyzerEventSecurityRating(client, "security-rating")
        self.system = FortianalyzerEventSystem(client, "system")
        self.user = FortianalyzerEventUser(client, "user")
        self.vpn = FortianalyzerEventVpn(client, "vpn")
        self.wad = FortianalyzerEventWad(client, "wad")
        self.wireless = FortianalyzerEventWireless(client, "wireless")


class FortianalyzerEventComplianceCheck:
    """event logs for compliance-check."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventComplianceCheck."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get compliance-check event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventConnector:
    """event logs for connector."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventConnector."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get connector event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventEndpoint:
    """event logs for endpoint."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventEndpoint."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get endpoint event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventFortiextender:
    """event logs for fortiextender."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventFortiextender."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get fortiextender event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventHa:
    """event logs for ha."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventHa."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get ha event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventRouter:
    """event logs for router."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventRouter."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get router event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventSecurityRating:
    """event logs for security-rating."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventSecurityRating."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get security-rating event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventSystem:
    """event logs for system."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventSystem."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get system event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventUser:
    """event logs for user."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventUser."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get user event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventVpn:
    """event logs for vpn."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventVpn."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get vpn event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventWad:
    """event logs for wad."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventWad."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get wad event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerEventWireless:
    """event logs for wireless."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerEventWireless."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get wireless event logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/event/{self._subtype}/raw", **kwargs)


class FortianalyzerFileFilter:
    """FortianalyzerFileFilter log operations (type=file-filter)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerFileFilter."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get file_filter logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/file-filter/raw", **kwargs)


class FortianalyzerGtp:
    """FortianalyzerGtp log operations (type=gtp)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerGtp."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get gtp logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/gtp/raw", **kwargs)


class FortianalyzerIps:
    """FortianalyzerIps log operations (type=ips)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerIps."""
        self._client = client
        self.archive = FortianalyzerIpsArchive(client, "ips")
        self.archive_download = FortianalyzerIpsArchiveDownload(client, "ips")

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get ips logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/ips/raw", **kwargs)


class FortianalyzerIpsArchive:
    """archive operations for ips."""

    def __init__(self, client: "IHTTPClient", type_value: str):
        """Initialize FortianalyzerIpsArchive."""
        self._client = client
        self._type = type_value

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get archive data for this log type.
        
        Args:
            **kwargs: Additional query parameters
        
        Returns:
            Dict containing archive data
        """
        return self._client.get("log", "/log/fortianalyzer/ips/archive", **kwargs)


class FortianalyzerIpsArchiveDownload:
    """archive-download operations for ips."""

    def __init__(self, client: "IHTTPClient", type_value: str):
        """Initialize FortianalyzerIpsArchiveDownload."""
        self._client = client
        self._type = type_value

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get archive-download data for this log type.
        
        Args:
            **kwargs: Additional query parameters
        
        Returns:
            Dict containing archive-download data
        """
        return self._client.get("log", "/log/fortianalyzer/ips/archive-download", **kwargs)


class FortianalyzerSsh:
    """FortianalyzerSsh log operations (type=ssh)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerSsh."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get ssh logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/ssh/raw", **kwargs)


class FortianalyzerSsl:
    """FortianalyzerSsl log operations (type=ssl)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerSsl."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get ssl logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/ssl/raw", **kwargs)


class FortianalyzerTraffic:
    """FortianalyzerTraffic log operations."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerTraffic."""
        self._client = client
        self.fortiview = FortianalyzerTrafficFortiview(client, "fortiview")
        self.forward = FortianalyzerTrafficForward(client, "forward")
        self.local = FortianalyzerTrafficLocal(client, "local")
        self.multicast = FortianalyzerTrafficMulticast(client, "multicast")
        self.sniffer = FortianalyzerTrafficSniffer(client, "sniffer")
        self.threat = FortianalyzerTrafficThreat(client, "threat")


class FortianalyzerTrafficFortiview:
    """traffic logs for fortiview."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerTrafficFortiview."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get fortiview traffic logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/traffic/{self._subtype}/raw", **kwargs)


class FortianalyzerTrafficForward:
    """traffic logs for forward."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerTrafficForward."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get forward traffic logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/traffic/{self._subtype}/raw", **kwargs)


class FortianalyzerTrafficLocal:
    """traffic logs for local."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerTrafficLocal."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get local traffic logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/traffic/{self._subtype}/raw", **kwargs)


class FortianalyzerTrafficMulticast:
    """traffic logs for multicast."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerTrafficMulticast."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get multicast traffic logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/traffic/{self._subtype}/raw", **kwargs)


class FortianalyzerTrafficSniffer:
    """traffic logs for sniffer."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerTrafficSniffer."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get sniffer traffic logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/traffic/{self._subtype}/raw", **kwargs)


class FortianalyzerTrafficThreat:
    """traffic logs for threat."""

    def __init__(self, client: "IHTTPClient", subtype: str):
        """Initialize FortianalyzerTrafficThreat."""
        self._client = client
        self._subtype = subtype

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get threat traffic logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return (default: 100)
                session_id (int): Session ID for paginated retrieval
                filter (str): Filter expression (e.g., "srcip==192.168.1.1")
                serial_no (str): Retrieve logs from specific device
        
        Returns:
            Dict with log records and metadata
        """
        return self._client.get("log", f"/log/fortianalyzer/traffic/{self._subtype}/raw", **kwargs)


class FortianalyzerVirus:
    """FortianalyzerVirus log operations (type=virus)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerVirus."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get virus logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/virus/raw", **kwargs)


class FortianalyzerVoip:
    """FortianalyzerVoip log operations (type=voip)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerVoip."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get voip logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/voip/raw", **kwargs)


class FortianalyzerWaf:
    """FortianalyzerWaf log operations (type=waf)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerWaf."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get waf logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/waf/raw", **kwargs)


class FortianalyzerWebfilter:
    """FortianalyzerWebfilter log operations (type=webfilter)."""

    def __init__(self, client: "IHTTPClient"):
        """Initialize FortianalyzerWebfilter."""
        self._client = client

    def get(self, **kwargs: Any) -> Union[dict[str, Any], Coroutine[Any, Any, dict[str, Any]]]:
        """
        Get webfilter logs.
        
        Args:
            **kwargs: Query parameters:
                rows (int): Number of log rows to return
                session_id (int): Session ID for continued retrieval
                filter (str): Filter expression(s)
        
        Returns:
            Dict containing log records
        """
        return self._client.get("log", "/log/fortianalyzer/webfilter/raw", **kwargs)



from typing import TypedDict, Literal, NotRequired, Any, Coroutine, Union, overload, Generator, final
from hfortix_fortios.models import FortiObject
from hfortix_core.types import MutationResponse, RawAPIResponse

# Payload TypedDict for IDE autocomplete (for POST/PUT - fields are optional via total=False)
# NOTE: We intentionally DON'T use NotRequired wrapper because:
# 1. total=False already makes all fields optional
# 2. NotRequired[Literal[...]] prevents Pylance from validating Literal values in dict literals
class ProxyAddressPayload(TypedDict, total=False):
    """
    Type hints for firewall/proxy_address payload fields.
    
    Configure web proxy address.
    
    **Related Resources:**

    Dependencies (resources this endpoint references):
        - :class:`~.firewall.address.AddressEndpoint` (via: host)
        - :class:`~.firewall.addrgrp.AddrgrpEndpoint` (via: host)
        - :class:`~.firewall.proxy-address.ProxyAddressEndpoint` (via: host)
        - :class:`~.firewall.vip.VipEndpoint` (via: host)
        - :class:`~.firewall.vipgrp.VipgrpEndpoint` (via: host)

    **Usage:**
        payload: ProxyAddressPayload = {
            "field": "value",  # <- autocomplete shows all fields
        }
    """
    name: str  # Address name. | MaxLen: 79
    uuid: str  # Universally Unique Identifier | Default: 00000000-0000-0000-0000-000000000000
    type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"]  # Proxy address type. | Default: url
    host: str  # Address object for the host. | MaxLen: 79
    host_regex: str  # Host name as a regular expression. | MaxLen: 255
    path: str  # URL path as a regular expression. | MaxLen: 255
    query: str  # Match the query part of the URL as a regular expre | MaxLen: 255
    referrer: Literal["enable", "disable"]  # Enable/disable use of referrer field in the HTTP h | Default: disable
    category: list[dict[str, Any]]  # FortiGuard category ID.
    method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"]  # HTTP request methods to be used.
    ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"]  # Names of browsers to be used as user agent.
    ua_min_ver: str  # Minimum version of the user agent specified in dot | MaxLen: 63
    ua_max_ver: str  # Maximum version of the user agent specified in dot | MaxLen: 63
    header_name: str  # Name of HTTP header. | MaxLen: 79
    header: str  # HTTP header name as a regular expression. | MaxLen: 255
    case_sensitivity: Literal["disable", "enable"]  # Enable to make the pattern case sensitive. | Default: disable
    header_group: list[dict[str, Any]]  # HTTP header group.
    color: int  # Integer value to determine the color of the icon i | Default: 0 | Min: 0 | Max: 32
    tagging: list[dict[str, Any]]  # Config object tagging.
    comment: str  # Optional comments. | MaxLen: 255
    application: list[dict[str, Any]]  # SaaS application.

# Nested TypedDicts for table field children (dict mode)

class ProxyAddressCategoryItem(TypedDict):
    """Type hints for category table item fields (dict mode).
    
    Provides IDE autocomplete for nested table field items.
    All fields are present in API responses.
    """
    
    id: int  # FortiGuard category ID. | Default: 0 | Min: 0 | Max: 4294967295


class ProxyAddressHeadergroupItem(TypedDict):
    """Type hints for header-group table item fields (dict mode).
    
    Provides IDE autocomplete for nested table field items.
    All fields are present in API responses.
    """
    
    id: int  # ID. | Default: 0 | Min: 0 | Max: 4294967295
    header_name: str  # HTTP header. | MaxLen: 79
    header: str  # HTTP header regular expression. | MaxLen: 255
    case_sensitivity: Literal["disable", "enable"]  # Case sensitivity in pattern. | Default: disable


class ProxyAddressTaggingItem(TypedDict):
    """Type hints for tagging table item fields (dict mode).
    
    Provides IDE autocomplete for nested table field items.
    All fields are present in API responses.
    """
    
    name: str  # Tagging entry name. | MaxLen: 63
    category: str  # Tag category. | MaxLen: 63
    tags: str  # Tags.


class ProxyAddressApplicationItem(TypedDict):
    """Type hints for application table item fields (dict mode).
    
    Provides IDE autocomplete for nested table field items.
    All fields are present in API responses.
    """
    
    name: str  # SaaS application name. | MaxLen: 79


# Nested classes for table field children (object mode)

@final
class ProxyAddressCategoryObject:
    """Typed object for category table items.
    
    Provides IDE autocomplete for nested table field attributes.
    At runtime, this is a FortiObject instance.
    """
    
    # FortiGuard category ID. | Default: 0 | Min: 0 | Max: 4294967295
    id: int
    
    # Methods from FortiObject
    def get_full(self, name: str) -> Any: ...
    def to_dict(self) -> dict[str, Any]: ...
    def keys(self) -> Any: ...
    def values(self) -> Generator[Any, None, None]: ...
    def items(self) -> Generator[tuple[str, Any], None, None]: ...
    def get(self, key: str, default: Any = None) -> Any: ...
    def __getitem__(self, key: str) -> Any: ...


@final
class ProxyAddressHeadergroupObject:
    """Typed object for header-group table items.
    
    Provides IDE autocomplete for nested table field attributes.
    At runtime, this is a FortiObject instance.
    """
    
    # ID. | Default: 0 | Min: 0 | Max: 4294967295
    id: int
    # HTTP header. | MaxLen: 79
    header_name: str
    # HTTP header regular expression. | MaxLen: 255
    header: str
    # Case sensitivity in pattern. | Default: disable
    case_sensitivity: Literal["disable", "enable"]
    
    # Methods from FortiObject
    def get_full(self, name: str) -> Any: ...
    def to_dict(self) -> dict[str, Any]: ...
    def keys(self) -> Any: ...
    def values(self) -> Generator[Any, None, None]: ...
    def items(self) -> Generator[tuple[str, Any], None, None]: ...
    def get(self, key: str, default: Any = None) -> Any: ...
    def __getitem__(self, key: str) -> Any: ...


@final
class ProxyAddressTaggingObject:
    """Typed object for tagging table items.
    
    Provides IDE autocomplete for nested table field attributes.
    At runtime, this is a FortiObject instance.
    """
    
    # Tagging entry name. | MaxLen: 63
    name: str
    # Tag category. | MaxLen: 63
    category: str
    # Tags.
    tags: str
    
    # Methods from FortiObject
    def get_full(self, name: str) -> Any: ...
    def to_dict(self) -> dict[str, Any]: ...
    def keys(self) -> Any: ...
    def values(self) -> Generator[Any, None, None]: ...
    def items(self) -> Generator[tuple[str, Any], None, None]: ...
    def get(self, key: str, default: Any = None) -> Any: ...
    def __getitem__(self, key: str) -> Any: ...


@final
class ProxyAddressApplicationObject:
    """Typed object for application table items.
    
    Provides IDE autocomplete for nested table field attributes.
    At runtime, this is a FortiObject instance.
    """
    
    # SaaS application name. | MaxLen: 79
    name: str
    
    # Methods from FortiObject
    def get_full(self, name: str) -> Any: ...
    def to_dict(self) -> dict[str, Any]: ...
    def keys(self) -> Any: ...
    def values(self) -> Generator[Any, None, None]: ...
    def items(self) -> Generator[tuple[str, Any], None, None]: ...
    def get(self, key: str, default: Any = None) -> Any: ...
    def __getitem__(self, key: str) -> Any: ...



# Response TypedDict for GET returns (all fields present in API response)
class ProxyAddressResponse(TypedDict):
    """
    Type hints for firewall/proxy_address API response fields.
    
    All fields are present in the response from the FortiGate API.
    """
    name: str  # Address name. | MaxLen: 79
    uuid: str  # Universally Unique Identifier | Default: 00000000-0000-0000-0000-000000000000
    type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"]  # Proxy address type. | Default: url
    host: str  # Address object for the host. | MaxLen: 79
    host_regex: str  # Host name as a regular expression. | MaxLen: 255
    path: str  # URL path as a regular expression. | MaxLen: 255
    query: str  # Match the query part of the URL as a regular expre | MaxLen: 255
    referrer: Literal["enable", "disable"]  # Enable/disable use of referrer field in the HTTP h | Default: disable
    category: list[ProxyAddressCategoryItem]  # FortiGuard category ID.
    method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"]  # HTTP request methods to be used.
    ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"]  # Names of browsers to be used as user agent.
    ua_min_ver: str  # Minimum version of the user agent specified in dot | MaxLen: 63
    ua_max_ver: str  # Maximum version of the user agent specified in dot | MaxLen: 63
    header_name: str  # Name of HTTP header. | MaxLen: 79
    header: str  # HTTP header name as a regular expression. | MaxLen: 255
    case_sensitivity: Literal["disable", "enable"]  # Enable to make the pattern case sensitive. | Default: disable
    header_group: list[ProxyAddressHeadergroupItem]  # HTTP header group.
    color: int  # Integer value to determine the color of the icon i | Default: 0 | Min: 0 | Max: 32
    tagging: list[ProxyAddressTaggingItem]  # Config object tagging.
    comment: str  # Optional comments. | MaxLen: 255
    application: list[ProxyAddressApplicationItem]  # SaaS application.


@final
class ProxyAddressObject:
    """Typed FortiObject for firewall/proxy_address with IDE autocomplete support.
    
    This is a typed wrapper that provides IDE autocomplete for API response fields.
    At runtime, this is actually a FortiObject instance.
    """
    
    # Address name. | MaxLen: 79
    name: str
    # Universally Unique Identifier | Default: 00000000-0000-0000-0000-000000000000
    uuid: str
    # Proxy address type. | Default: url
    type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"]
    # Address object for the host. | MaxLen: 79
    host: str
    # Host name as a regular expression. | MaxLen: 255
    host_regex: str
    # URL path as a regular expression. | MaxLen: 255
    path: str
    # Match the query part of the URL as a regular expression. | MaxLen: 255
    query: str
    # Enable/disable use of referrer field in the HTTP header to m | Default: disable
    referrer: Literal["enable", "disable"]
    # FortiGuard category ID.
    category: list[ProxyAddressCategoryObject]
    # HTTP request methods to be used.
    method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"]
    # Names of browsers to be used as user agent.
    ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"]
    # Minimum version of the user agent specified in dotted notati | MaxLen: 63
    ua_min_ver: str
    # Maximum version of the user agent specified in dotted notati | MaxLen: 63
    ua_max_ver: str
    # Name of HTTP header. | MaxLen: 79
    header_name: str
    # HTTP header name as a regular expression. | MaxLen: 255
    header: str
    # Enable to make the pattern case sensitive. | Default: disable
    case_sensitivity: Literal["disable", "enable"]
    # HTTP header group.
    header_group: list[ProxyAddressHeadergroupObject]
    # Integer value to determine the color of the icon in the GUI | Default: 0 | Min: 0 | Max: 32
    color: int
    # Config object tagging.
    tagging: list[ProxyAddressTaggingObject]
    # Optional comments. | MaxLen: 255
    comment: str
    # SaaS application.
    application: list[ProxyAddressApplicationObject]
    
    # Common API response fields
    status: str
    http_status: int | None
    vdom: str | None
    
    # Methods from FortiObject
    def get_full(self, name: str) -> Any: ...
    def to_dict(self) -> ProxyAddressPayload: ...
    def keys(self) -> Any: ...
    def values(self) -> Generator[Any, None, None]: ...
    def items(self) -> Generator[tuple[str, Any], None, None]: ...
    def get(self, key: str, default: Any = None) -> Any: ...
    def __getitem__(self, key: str) -> Any: ...


class ProxyAddress:
    """
    Configure web proxy address.
    
    Path: firewall/proxy_address
    Category: cmdb
    Primary Key: name
    """
    
    # ================================================================
    # DEFAULT MODE OVERLOADS (no response_mode) - MUST BE FIRST
    # These match when response_mode is NOT passed (client default is "dict")
    # Pylance matches overloads top-to-bottom, so these must come first!
    # ================================================================
    
    # Default mode: mkey as positional arg -> returns typed dict
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
    ) -> ProxyAddressResponse: ...
    
    # Default mode: mkey as keyword arg -> returns typed dict
    @overload
    def get(
        self,
        *,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
    ) -> ProxyAddressResponse: ...
    
    # Default mode: no mkey -> returns list of typed dicts
    @overload
    def get(
        self,
        name: None = None,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
    ) -> list[ProxyAddressResponse]: ...
    
    # ================================================================
    # EXPLICIT response_mode="object" OVERLOADS
    # ================================================================
    
    # Object mode: mkey as positional arg -> returns single object
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # Object mode: mkey as keyword arg -> returns single object
    @overload
    def get(
        self,
        *,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # Object mode: no mkey -> returns list of objects
    @overload
    def get(
        self,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> list[ProxyAddressObject]: ...
    
    # raw_json=True returns the full API envelope
    @overload
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[True] = ...,
        response_mode: Literal["object"] = ...,
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Dict mode with mkey provided as positional arg (single dict)
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] = ...,
        **kwargs: Any,
    ) -> ProxyAddressResponse: ...
    
    # Dict mode with mkey provided as keyword arg (single dict)
    @overload
    def get(
        self,
        *,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] = ...,
        **kwargs: Any,
    ) -> ProxyAddressResponse: ...
    
    # Dict mode - list of dicts (no mkey/name provided) - keyword-only signature
    @overload
    def get(
        self,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] = ...,
        **kwargs: Any,
    ) -> list[ProxyAddressResponse]: ...
    
    # Fallback overload for all other cases
    @overload
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict", "object"] | None = ...,
        **kwargs: Any,
    ) -> Union[dict[str, Any], list[dict[str, Any]], FortiObject, list[FortiObject]]: ...
    
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: str | None = ...,
        **kwargs: Any,
    ) -> ProxyAddressObject | list[ProxyAddressObject] | dict[str, Any] | list[dict[str, Any]]: ...
    
    def get_schema(
        self,
        vdom: str | None = ...,
        format: str = ...,
    ) -> dict[str, Any]: ...
    
    # POST overloads
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # raw_json=True returns the full API envelope
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[True] = ...,
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Default overload (no response_mode or raw_json specified)
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict", "object"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # PUT overloads
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # raw_json=True returns the full API envelope
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[True] = ...,
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Default overload (no response_mode or raw_json specified)
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict", "object"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # DELETE overloads
    @overload
    def delete(
        self,
        name: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    @overload
    def delete(
        self,
        name: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # raw_json=True returns the full API envelope
    @overload
    def delete(
        self,
        name: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[True] = ...,
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Default overload (no response_mode or raw_json specified)
    @overload
    def delete(
        self,
        name: str | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    def delete(
        self,
        name: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    def exists(
        self,
        name: str,
        vdom: str | bool | None = ...,
    ) -> bool: ...
    
    def set(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict", "object"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # Helper methods
    @staticmethod
    def help(field_name: str | None = ...) -> str: ...
    
    @staticmethod
    def fields(detailed: bool = ...) -> Union[list[str], list[dict[str, Any]]]: ...
    
    @staticmethod
    def field_info(field_name: str) -> dict[str, Any]: ...
    
    @staticmethod
    def validate_field(name: str, value: Any) -> bool: ...
    
    @staticmethod
    def required_fields() -> list[str]: ...
    
    @staticmethod
    def defaults() -> dict[str, Any]: ...
    
    @staticmethod
    def schema() -> dict[str, Any]: ...


# ================================================================
# MODE-SPECIFIC CLASSES FOR CLIENT-LEVEL response_mode SUPPORT
# ================================================================

class ProxyAddressDictMode:
    """ProxyAddress endpoint for dict response mode (default for this client).
    
    By default returns ProxyAddressResponse (TypedDict).
    Can be overridden per-call with response_mode="object" to return ProxyAddressObject.
    """
    
    # raw_json=True returns RawAPIResponse regardless of response_mode
    @overload
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Object mode override with mkey (single item)
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # Object mode override without mkey (list)
    @overload
    def get(
        self,
        name: None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> list[ProxyAddressObject]: ...
    
    # Dict mode with mkey (single item) - default
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict"] | None = ...,
        **kwargs: Any,
    ) -> ProxyAddressResponse: ...
    
    # Dict mode without mkey (list) - default
    @overload
    def get(
        self,
        name: None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict"] | None = ...,
        **kwargs: Any,
    ) -> list[ProxyAddressResponse]: ...

    # raw_json=True returns RawAPIResponse for POST
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # POST - Object mode override
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # POST - Default overload (returns MutationResponse)
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # POST - Dict mode (default for DictMode class)
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...

    # raw_json=True returns RawAPIResponse for PUT
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # PUT - Object mode override
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # PUT - Default overload (returns MutationResponse)
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # PUT - Dict mode (default for DictMode class)
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...

    # raw_json=True returns RawAPIResponse for DELETE
    @overload
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # DELETE - Object mode override
    @overload
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # DELETE - Default overload (returns MutationResponse)
    @overload
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # DELETE - Dict mode (default for DictMode class)
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...


class ProxyAddressObjectMode:
    """ProxyAddress endpoint for object response mode (default for this client).
    
    By default returns ProxyAddressObject (FortiObject).
    Can be overridden per-call with response_mode="dict" to return ProxyAddressResponse (TypedDict).
    """
    
    # raw_json=True returns RawAPIResponse for GET
    @overload
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Dict mode override with mkey (single item)
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        *,
        response_mode: Literal["dict"],
        **kwargs: Any,
    ) -> ProxyAddressResponse: ...
    
    # Dict mode override without mkey (list)
    @overload
    def get(
        self,
        name: None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        *,
        response_mode: Literal["dict"],
        **kwargs: Any,
    ) -> list[ProxyAddressResponse]: ...
    
    # Object mode with mkey (single item) - default
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["object"] | None = ...,
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # Object mode without mkey (list) - default
    @overload
    def get(
        self,
        name: None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["object"] | None = ...,
        **kwargs: Any,
    ) -> list[ProxyAddressObject]: ...

    # raw_json=True returns RawAPIResponse for POST
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # POST - Dict mode override
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["dict"],
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # POST - Object mode override (requires explicit response_mode="object")
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # POST - Default overload (no response_mode specified, returns Object for ObjectMode)
    @overload
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # POST - Default for ObjectMode (returns MutationResponse like DictMode)
    def post(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...

    # PUT - Dict mode override
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["dict"],
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # raw_json=True returns RawAPIResponse for PUT
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # PUT - Object mode override (requires explicit response_mode="object")
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # PUT - Default overload (no response_mode specified, returns Object for ObjectMode)
    @overload
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # PUT - Default for ObjectMode (returns MutationResponse like DictMode)
    def put(
        self,
        payload_dict: ProxyAddressPayload | None = ...,
        name: str | None = ...,
        uuid: str | None = ...,
        type: Literal["host-regex", "url", "category", "method", "ua", "header", "src-advanced", "dst-advanced", "saas"] | None = ...,
        host: str | None = ...,
        host_regex: str | None = ...,
        path: str | None = ...,
        query: str | None = ...,
        referrer: Literal["enable", "disable"] | None = ...,
        category: str | list[str] | list[dict[str, Any]] | None = ...,
        method: Literal["get", "post", "put", "head", "connect", "trace", "options", "delete", "update", "patch", "other"] | list[str] | None = ...,
        ua: Literal["chrome", "ms", "firefox", "safari", "ie", "edge", "other"] | list[str] | None = ...,
        ua_min_ver: str | None = ...,
        ua_max_ver: str | None = ...,
        header_name: str | None = ...,
        header: str | None = ...,
        case_sensitivity: Literal["disable", "enable"] | None = ...,
        header_group: str | list[str] | list[dict[str, Any]] | None = ...,
        color: int | None = ...,
        tagging: str | list[str] | list[dict[str, Any]] | None = ...,
        comment: str | None = ...,
        application: str | list[str] | list[dict[str, Any]] | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...

    # raw_json=True returns RawAPIResponse for DELETE
    @overload
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # DELETE - Dict mode override
    @overload
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["dict"],
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # DELETE - Object mode override (requires explicit response_mode="object")
    @overload
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # DELETE - Default overload (no response_mode specified, returns Object for ObjectMode)
    @overload
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> ProxyAddressObject: ...
    
    # DELETE - Default for ObjectMode (returns MutationResponse like DictMode)
    def delete(
        self,
        name: str,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...


__all__ = [
    "ProxyAddress",
    "ProxyAddressDictMode",
    "ProxyAddressObjectMode",
    "ProxyAddressPayload",
    "ProxyAddressObject",
]